@@ -1,5 +1,5 @@
 ## File Name: zzz.R
-## File Version: 0.12
+## File Version: 0.13
 #  zzz.R
 #
 # This function is simply copied from the mice package.
@@ -20,3 +20,12 @@ version <- function(pkg="mdmb")
     d <- utils::packageDescription(pkg)
     return( paste(d$Package,d$Version,d$Date,lib))
 }
+
+
+xx <- function(f1, f2)
+{
+    v1 <- paste0( rep(" ",f1), collapse="" )
+    v2 <- paste0( rep(" ",f2), collapse="" )
+    res <- paste0( v1, "=", v2)
+    return(res)
+}
